@@ -35,6 +35,7 @@
 #include <KXmlGuiWindow>
 
 class KNotificationRestrictions;
+class KToggleAction;
 class KUrl;
 class QActionGroup;
 class QCloseEvent;
@@ -89,6 +90,7 @@ namespace Dragon
       void subChannelsChanged( QList< QAction* > );
       void audioChannelsChanged( QList< QAction* > );
       void mutedChanged( bool );
+      void stop();
       //in stateChange.cpp
       void engineStateChanged( Phonon::State, Phonon::State = Phonon::StoppedState);
       void engineMediaChanged( Phonon::MediaSource );
@@ -96,8 +98,6 @@ namespace Dragon
       void engineMetaDataChanged();
       void engineHasVideoChanged( bool );
 
-
-
    private:
       bool load( const KUrl& );
       void setupActions();
@@ -111,6 +111,9 @@ namespace Dragon
       virtual void dropEvent( QDropEvent* );
       virtual void keyPressEvent( QKeyEvent* );
 
+      void inhibitPowerSave();
+      void releasePowerSave();
+
 //      virtual void saveProperties( KConfig* );
 //      virtual void readProperties( KConfig* );
 
@@ -129,6 +132,8 @@ namespace Dragon
       QList<QSlider*> m_sliders;
       QPointer<PlayDialog> m_playDialog;
 
+      KToggleAction *m_menuToggleAction;
+
       KNotificationRestrictions *m_stopScreenSaver;
       int m_screensaverDisableCookie;
       int m_stopSleepCookie;
@@ -136,6 +141,7 @@ namespace Dragon
 
       bool m_toolbarIsHidden;
       bool m_statusbarIsHidden;
+      bool m_menuBarIsHidden;
       FullScreenToolBarHandler *m_FullScreenHandler;
 
       QActionGroup *m_aspectRatios;
